@@ -14,7 +14,6 @@
 #'
 #' @return A `ggplot` object
 #'
-#' @import ggplot2
 #' @export
 #'
 #' @family explanation plots
@@ -38,36 +37,69 @@ plot_features <- function(explanation, ncol = 2, cases = NULL) {
   if (!is.null(cases)) {
     explanation <- explanation[explanation$case %in% cases, , drop = FALSE]
   }
-  if (nrow(explanation) == 0) stop("No explanations to plot", call. = FALSE)
+  if (nrow(explanation) == 0) {
+    stop("No explanations to plot", call. = FALSE)
+  }
 
   if (explanation$model_type[1] == 'regression') {
     type_pal <- c('Positive', 'Negative')
     binned_feature <- grepl("=|>|<", explanation$feature_desc)
-    explanation[!binned_feature, "feature_weight"] <- as.numeric(explanation$feature_value[!binned_feature]) * explanation$feature_weight[!binned_feature]
+    explanation[
+      !binned_feature,
+      "feature_weight"
+    ] <- as.numeric(explanation$feature_value[!binned_feature]) *
+      explanation$feature_weight[!binned_feature]
   }
 
-  explanation$type <- factor(ifelse(sign(explanation$feature_weight) == 1, type_pal[1], type_pal[2]), levels = type_pal)
+  explanation$type <- factor(
+    ifelse(sign(explanation$feature_weight) == 1, type_pal[1], type_pal[2]),
+    levels = type_pal
+  )
   description <- paste0(explanation$case, '_', explanation[['label']])
   desc_width <- max(nchar(description)) + 1
-  description <- paste0(format(description, width = desc_width), explanation$feature_desc)
-  explanation$description <- factor(description, levels = description[order(abs(explanation$feature_weight))])
+  description <- paste0(
+    format(description, width = desc_width),
+    explanation$feature_desc
+  )
+  explanation$description <- factor(
+    description,
+    levels = description[order(abs(explanation$feature_weight))]
+  )
   explanation$case <- factor(explanation$case, unique(explanation$case))
   explanation$`Explanation fit` <- format(explanation$model_r2, digits = 2)
 
   if (explanation$model_type[1] == 'classification') {
     explanation$probability <- format(explanation$label_prob, digits = 2)
-    explanation$label <- factor(explanation$label, unique(explanation$label[order(explanation$label_prob, decreasing = TRUE)]))
+    explanation$label <- factor(
+      explanation$label,
+      unique(explanation$label[order(
+        explanation$label_prob,
+        decreasing = TRUE
+      )])
+    )
     p <- ggplot(explanation) +
-      facet_wrap(~ case + label + probability + `Explanation fit`, labeller = label_both_upper, scales = 'free_y', ncol = ncol)
+      facet_wrap(
+        ~ case + label + probability + `Explanation fit`,
+        labeller = label_both_upper,
+        scales = 'free_y',
+        ncol = ncol
+      )
   } else if (explanation$model_type[1] == 'regression') {
     p <- ggplot(explanation) +
-      facet_wrap(~ case + prediction + `Explanation fit`, labeller = label_both_upper, scales = 'free_y', ncol = ncol)
+      facet_wrap(
+        ~ case + prediction + `Explanation fit`,
+        labeller = label_both_upper,
+        scales = 'free_y',
+        ncol = ncol
+      )
   }
   p +
     geom_col(aes_(~description, ~feature_weight, fill = ~type)) +
     coord_flip() +
     scale_fill_manual(values = c('steelblue', 'firebrick'), drop = FALSE) +
-    scale_x_discrete(labels = function(lab) substr(lab, desc_width + 1, nchar(lab))) +
+    scale_x_discrete(labels = function(lab) {
+      substr(lab, desc_width + 1, nchar(lab))
+    }) +
     labs(y = 'Weight', x = 'Feature', fill = '') +
     theme_lime()
 }
@@ -84,7 +116,6 @@ plot_features <- function(explanation, ncol = 2, cases = NULL) {
 #'
 #' @return A `ggplot` object
 #'
-#' @import ggplot2
 #' @export
 #'
 #' @family explanation plots
@@ -104,22 +135,35 @@ plot_features <- function(explanation, ncol = 2, cases = NULL) {
 plot_explanations <- function(explanation, ...) {
   num_cases <- unique(suppressWarnings(as.numeric(explanation$case)))
   if (!anyNA(num_cases)) {
-    explanation$case <- factor(explanation$case, levels = as.character(sort(num_cases)))
+    explanation$case <- factor(
+      explanation$case,
+      levels = as.character(sort(num_cases))
+    )
   }
   explanation$feature_desc <- factor(
     explanation$feature_desc,
-    levels = rev(unique(explanation$feature_desc[order(explanation$feature, explanation$feature_value)]))
+    levels = rev(unique(explanation$feature_desc[order(
+      explanation$feature,
+      explanation$feature_value
+    )]))
   )
   p <- ggplot(explanation, aes_(~case, ~feature_desc)) +
     geom_tile(aes_(fill = ~feature_weight)) +
     scale_x_discrete('Case', expand = c(0, 0)) +
     scale_y_discrete('Feature', expand = c(0, 0)) +
-    scale_fill_gradient2('Feature\nweight', low = 'firebrick', mid = '#f7f7f7', high = 'steelblue') +
+    scale_fill_gradient2(
+      'Feature\nweight',
+      low = 'firebrick',
+      mid = '#f7f7f7',
+      high = 'steelblue'
+    ) +
     theme_lime() +
-    theme(panel.border = element_rect(fill = NA, colour = 'grey60', size = 1),
-          panel.grid = element_blank(),
-          legend.position = 'right',
-          axis.text.x = element_text(angle = 45, hjust = 1, vjust = 1))
+    theme(
+      panel.border = element_rect(fill = NA, colour = 'grey60', size = 1),
+      panel.grid = element_blank(),
+      legend.position = 'right',
+      axis.text.x = element_text(angle = 45, hjust = 1, vjust = 1)
+    )
   if (is.null(explanation$label)) {
     p
   } else {
@@ -145,7 +189,6 @@ theme_lime <- function(...) {
       ...
     )
 }
-#' @importFrom tools toTitleCase
 label_both_upper <- function(labels, multi_line = TRUE, sep = ': ') {
   names(labels) <- toTitleCase(names(labels))
   label_both(labels, multi_line, sep)
