@@ -1,4 +1,3 @@
-context("data.frame")
 library(MASS)
 
 test_that("lime explanation only produces one entry per case and feature", {
@@ -13,6 +12,12 @@ test_that("lime explanation only produces one entry per case and feature", {
   explainer <- lime(iris_train, model)
 
   # Explain new observation. This should yield a tibble with one row, because it's one case, one feature, one label
-  explanations <- explain(iris_train[1,], explainer, n_labels = 1, n_features = 1, feature_select = 'forward_selection')
+  explanations <- explain(
+    iris_train[1, ],
+    explainer,
+    n_labels = 1,
+    n_features = 1,
+    feature_select = 'forward_selection'
+  )
   expect_equal(nrow(explanations), 1)
 })
